@@ -24,16 +24,19 @@ import logging
 # settings re-grouped a bit
 def main():
     parser = argparse.ArgumentParser(description='cellpose parameters')
-    
+
     # settings for CPU vs GPU
     hardware_args = parser.add_argument_group("hardware arguments")
     hardware_args.add_argument('--use_gpu', action='store_true', help='use gpu if torch with cuda installed')
+    hardware_args.add_argument('--gpu_device', required=False, default='0', type=str, help='which gpu device to use, use an integer for torch, or mps for M1')
     hardware_args.add_argument('--check_mkl', action='store_true', help='check if mkl working')
         
     # settings for locating and formatting images
     input_img_args = parser.add_argument_group("input image arguments")
     input_img_args.add_argument('--dir',
                         default=[], type=str, help='folder containing data to run or train on.')
+    input_img_args.add_argument('--image_path',
+                        default=[], type=str, help='if given and --dir not given, run on single image instead of folder (cannot train with this option)')
     input_img_args.add_argument('--look_one_level_down', action='store_true', help='run processing on all subdirectories of current folder')
     input_img_args.add_argument('--img_filter',
                         default=[], type=str, help='end string for images to run on')
@@ -51,6 +54,7 @@ def main():
     # model settings 
     model_args = parser.add_argument_group("model arguments")
     model_args.add_argument('--pretrained_model', required=False, default='cyto', type=str, help='model to use for running or starting training')
+    model_args.add_argument('--add_model', required=False, default=None, type=str, help='model path to copy model to hidden .cellpose folder for using in GUI/CLI')
     model_args.add_argument('--unet', action='store_true', help='run standard unet instead of cellpose flow output')
     model_args.add_argument('--nclasses',default=3, type=int, help='if running unet, choose 2 or 3; cellpose always uses 3')
 
@@ -59,6 +63,7 @@ def main():
     algorithm_args.add_argument('--no_resample', action='store_true', help="disable dynamics on full image (makes algorithm faster for images with large diameters)")
     algorithm_args.add_argument('--net_avg', action='store_true', help='run 4 networks instead of 1 and average results')
     algorithm_args.add_argument('--no_interp', action='store_true', help='do not interpolate when running dynamics (was default)')
+    algorithm_args.add_argument('--no_norm', action='store_true', help='do not normalize images (normalize=False)')
     algorithm_args.add_argument('--do_3D', action='store_true', help='process images as 3D stacks of images (nplanes x nchan x Ly x Lx')
     algorithm_args.add_argument('--diameter', required=False, default=30., type=float, 
                         help='cell diameter, if 0 will use the diameter of the training labels used in the model, or with built-in model will estimate diameter for each image')
@@ -93,7 +98,7 @@ def main():
     training_args.add_argument('--test_dir',
                         default=[], type=str, help='folder containing test data (optional)')
     training_args.add_argument('--mask_filter',
-                        default='_masks', type=str, help='end string for masks to run on. Default: %(default)s')
+                        default='_masks', type=str, help='end string for masks to run on. use "_seg.npy" for manual annotations from the GUI. Default: %(default)s')
     training_args.add_argument('--diam_mean',
                         default=30., type=float, help='mean diameter to resize cells to during training -- if starting from pretrained models it cannot be changed from 30.0')
     training_args.add_argument('--learning_rate',
@@ -126,14 +131,17 @@ def main():
     else:
         mkl_enabled = True
     
-    if len(args.dir)==0:
-        if not GUI_ENABLED:
-            print('GUI ERROR: %s'%GUI_ERROR)
-            if GUI_IMPORT:
-                print('GUI FAILED: GUI dependencies may not be installed, to install, run')
-                print('     pip install cellpose[gui]')
+    if len(args.dir)==0 and len(args.image_path)==0:
+        if args.add_model:
+            io.add_model(args.add_model)
         else:
-            gui.run()
+            if not GUI_ENABLED:
+                print('GUI ERROR: %s'%GUI_ERROR)
+                if GUI_IMPORT:
+                    print('GUI FAILED: GUI dependencies may not be installed, to install, run')
+                    print('     pip install cellpose[gui]')
+            else:
+                gui.run()
 
     else:
         if args.verbose:
@@ -158,7 +166,7 @@ def main():
         if not (args.train or args.train_size):
             saving_something = args.save_png or args.save_tif or args.save_flows or args.save_ncolor or args.save_txt
                     
-        device, gpu = models.assign_device(use_torch=True, gpu=args.use_gpu)
+        device, gpu = models.assign_device(use_torch=True, gpu=args.use_gpu, device=args.gpu_device)
 
         if args.pretrained_model is None or args.pretrained_model == 'None' or args.pretrained_model == 'False' or args.pretrained_model == '0':
             pretrained_model = False
@@ -181,13 +189,21 @@ def main():
                 szmean = 30.
         builtin_size = model_type == 'cyto' or model_type == 'cyto2' or model_type == 'nuclei'
         
+        if len(args.image_path) > 0 and (args.train or args.train_size):
+            raise ValueError('ERROR: cannot train model with single image input')
+
         if not args.train and not args.train_size:
             tic = time.time()
-
-            image_names = io.get_image_files(args.dir, 
-                                             args.mask_filter, 
-                                             imf=imf,
-                                             look_one_level_down=args.look_one_level_down)
+            if len(args.dir) > 0:
+                image_names = io.get_image_files(args.dir, 
+                                                args.mask_filter, 
+                                                imf=imf,
+                                                look_one_level_down=args.look_one_level_down)
+            else:
+                if os.path.exists(args.image_path):
+                    image_names = [args.image_path]
+                else:
+                    raise ValueError(f'ERROR: no file found at {args.image_path}')
             nimg = len(image_names)
                 
             cstr0 = ['GRAY', 'RED', 'GREEN', 'BLUE']
@@ -237,6 +253,7 @@ def main():
                                 invert=args.invert,
                                 batch_size=args.batch_size,
                                 interp=(not args.no_interp),
+                                normalize=(not args.no_norm),
                                 channel_axis=args.channel_axis,
                                 z_axis=args.z_axis,
                                 anisotropy=args.anisotropy,
