@@ -3,12 +3,14 @@ import gc
 from natsort import natsorted
 from tqdm import tqdm, trange
 
+import PyQt5
 from PyQt5 import QtGui, QtCore, Qt, QtWidgets
 from PyQt5.QtWidgets import QMainWindow, QApplication, QWidget, QScrollBar, QSlider, QComboBox, QGridLayout, QPushButton, QFrame, QCheckBox, QLabel, QProgressBar, QLineEdit, QMessageBox, QGroupBox
 import pyqtgraph as pg
 from pyqtgraph import GraphicsScene
 
 import numpy as np
+from scipy.stats import mode
 import cv2
 
 from . import guiparts, menus, io
@@ -125,13 +127,18 @@ def run():
     app = QApplication(sys.argv)
     icon_path = pathlib.Path.home().joinpath('.cellpose', 'logo.png')
     guip_path = pathlib.Path.home().joinpath('.cellpose', 'cellpose_gui.png')
+    style_path = pathlib.Path.home().joinpath('.cellpose', 'style_choice.npy')
     if not icon_path.is_file():
         cp_dir = pathlib.Path.home().joinpath('.cellpose')
         cp_dir.mkdir(exist_ok=True)
         print('downloading logo')
         download_url_to_file('https://www.cellpose.org/static/images/cellpose_transparent.png', icon_path, progress=True)
     if not guip_path.is_file():
+        print('downloading help window image')
         download_url_to_file('https://www.cellpose.org/static/images/cellpose_gui.png', guip_path, progress=True)
+    if not style_path.is_file():
+        print('downloading style classifier')
+        download_url_to_file('https://www.cellpose.org/static/models/style_choice.npy', style_path, progress=True)
     icon_path = str(icon_path.resolve())
     app_icon = QtGui.QIcon()
     app_icon.addFile(icon_path, QtCore.QSize(16, 16))
@@ -180,7 +187,7 @@ class MainW(QMainWindow):
 
         self.setStyleSheet("QMainWindow {background: 'black';}")
         self.stylePressed = ("QPushButton {Text-align: left; "
-                             "background-color: rgb(100,50,100); "
+                             "background-color: rgb(150,50,150); "
                              "border-color: white;"
                              "color:white;}")
         self.styleUnpressed = ("QPushButton {Text-align: left; "
@@ -291,15 +298,10 @@ class MainW(QMainWindow):
         label.setFont(self.smallfont)
         self.l0.addWidget(label, 1,0,1,4)
 
-        label = QLabel('[pageup/down]')
-        label.setStyleSheet(label_style)
-        label.setFont(self.smallfont)
-        self.l0.addWidget(label, 1,5,1,5)
-
+        
         b=2
         self.view = 0 # 0=image, 1=flowsXY, 2=flowsZ, 3=cellprob
         self.color = 0 # 0=RGB, 1=gray, 2=R, 3=G, 4=B
-        self.RGBChoose = guiparts.RGBRadioButtons(self, b,5)
         self.RGBDropDown = QComboBox()
         self.RGBDropDown.addItems(["RGB","red=R","green=G","blue=B","gray","spectral"])
         self.RGBDropDown.setFont(self.medfont)
@@ -312,7 +314,14 @@ class MainW(QMainWindow):
         label = QLabel('[press R / G / B to \n toggle RGB and color ]')
         label.setStyleSheet(label_style)
         label.setFont(self.smallfont)
-        self.l0.addWidget(label, b+1,0,1,4)
+        self.l0.addWidget(label, b,4,1,4)
+
+        label = QLabel('[pageup/down]')
+        label.setStyleSheet(label_style)
+        label.setFont(self.smallfont)
+        self.l0.addWidget(label, b+1,0,1,5)
+        self.RGBChoose = guiparts.RGBRadioButtons(self, b+2,0)
+        
 
         b+=3
 
@@ -381,6 +390,14 @@ class MainW(QMainWindow):
         label.setStyleSheet(self.headings)
         label.setFont(self.boldfont)
         self.l0.addWidget(label, b,0,1,9)
+        
+        # use GPU
+        self.useGPU = QCheckBox('use GPU')
+        self.useGPU.setStyleSheet(self.checkstyle)
+        self.useGPU.setFont(self.medfont)
+        self.useGPU.setToolTip('if you have specially installed the <i>cuda</i> version of torch, then you can activate this')
+        self.check_gpu()
+        self.l0.addWidget(self.useGPU, b,5,1,4)
 
         b+=1
         self.diameter = 30
@@ -406,26 +423,6 @@ class MainW(QMainWindow):
         self.SizeButton.setStyleSheet(self.styleInactive)
         self.SizeButton.setFont(self.boldfont)
 
-        # scale toggle
-        b+=1
-        self.scale_on = True
-        self.ScaleOn = QCheckBox('scale disk on')
-        self.ScaleOn.setFont(self.medfont)
-        self.ScaleOn.setStyleSheet('color: red;')
-        self.ScaleOn.setChecked(True)
-        self.ScaleOn.setToolTip('see current diameter as red disk at bottom')
-        self.ScaleOn.toggled.connect(self.toggle_scale)
-        self.l0.addWidget(self.ScaleOn, b,0,1,5)
-
-        # use GPU
-        #b+=1
-        self.useGPU = QCheckBox('use GPU')
-        self.useGPU.setStyleSheet(self.checkstyle)
-        self.useGPU.setFont(self.medfont)
-        self.useGPU.setToolTip('if you have specially installed the <i>cuda</i> version of torch, then you can activate this')
-        self.check_gpu()
-        self.l0.addWidget(self.useGPU, b,5,1,4)
-
         ### fast mode
         #self.NetAvg = QComboBox()
         #self.NetAvg.addItems(['average 4 nets', 'run 1 net', '+ turn off resample (fast)'])
@@ -468,7 +465,7 @@ class MainW(QMainWindow):
         self.flow_threshold = QLineEdit()
         self.flow_threshold.setText('0.4')
         self.flow_threshold.returnPressed.connect(self.compute_cprob)
-        self.flow_threshold.setFixedWidth(60)
+        self.flow_threshold.setFixedWidth(70)
         self.l0.addWidget(self.flow_threshold, b,5,1,4)
 
         b+=1
@@ -480,9 +477,21 @@ class MainW(QMainWindow):
         self.cellprob_threshold = QLineEdit()
         self.cellprob_threshold.setText('0.0')
         self.cellprob_threshold.returnPressed.connect(self.compute_cprob)
-        self.cellprob_threshold.setFixedWidth(60)
+        self.cellprob_threshold.setFixedWidth(70)
         self.l0.addWidget(self.cellprob_threshold, b,5,1,4)
 
+        b+=1
+        label = QLabel('stitch_threshold:')
+        label.setToolTip('for 3D volumes, turn on stitch_threshold to stitch masks across planes instead of running cellpose in 3D (see docs for details)')
+        label.setStyleSheet(label_style)
+        label.setFont(self.medfont)
+        self.l0.addWidget(label, b, 0,1,5)
+        self.stitch_threshold = QLineEdit()
+        self.stitch_threshold.setText('0.0')
+        #self.cellprob_threshold.returnPressed.connect(self.compute_cprob)
+        self.stitch_threshold.setFixedWidth(70)
+        self.l0.addWidget(self.stitch_threshold, b,5,1,4)
+
         b+=1
         self.GB = QGroupBox('model zoo')
         self.GB.setStyleSheet("QGroupBox { border: 1px solid white; color:white; padding: 10px 0px;}")
@@ -490,15 +499,15 @@ class MainW(QMainWindow):
         self.GB.setLayout(self.GBg)
 
         # compute segmentation with general models
-        net_text = ['cyto','nuclei','tissuenet','livecell', 'cyto2']
+        self.net_text = ['cyto','nuclei','tissuenet','livecell', 'cyto2']
         nett = ['cellpose cyto model', 
                 'cellpose nuclei model',
-                'tissuenet cell model',
-                'livecell model',
+                'tissuenet cell model\n(non-commercial use only)',
+                'livecell model\n(non-commercial use only)',
                 'cellpose cyto2 model']
         self.StyleButtons = []
-        for j in range(len(net_text)):
-            self.StyleButtons.append(guiparts.ModelButton(self, net_text[j], net_text[j]))
+        for j in range(len(self.net_text)):
+            self.StyleButtons.append(guiparts.ModelButton(self, self.net_text[j], self.net_text[j]))
             self.GBg.addWidget(self.StyleButtons[-1], 0,2*j,1,2)
             if j < 4:
                 self.StyleButtons[-1].setFixedWidth(45)
@@ -507,17 +516,26 @@ class MainW(QMainWindow):
             self.StyleButtons[-1].setToolTip(nett[j])
 
         # compute segmentation with style model
-        net_text = ['CP', 'CPx', 'TN1', 'TN2', 'TN3', #'TN-p','TN-gi','TN-i',
-                    'LC1', 'LC2', 'LC3', 'LC4', #'LC-g','LC-e','LC-r','LC-n',
-                    ]
-        nett = ['cellpose cyto fluorescent', 'cellpose other', 'tissuenet 1', 'tissuenet 2', 'tissuenet 3',
-                'livecell A172 + SKOV3', 'livecell various', 'livecell BV2 + SkBr3', 'livecell SHSY5Y']
+        self.net_text.extend(['CP', 'CPx', 'TN1', 'TN2', 'TN3', #'TN-p','TN-gi','TN-i',
+                         'LC1', 'LC2', 'LC3', 'LC4', #'LC-g','LC-e','LC-r','LC-n',
+                        ])
+        nett = ['cellpose cyto fluorescent', 'cellpose other', 'tissuenet 1\n(non-commercial use only)', 
+                'tissuenet 2\n(non-commercial use only)', 'tissuenet 3\n(non-commercial use only)',
+                'livecell A172 + SKOV3\n(non-commercial use only)', 'livecell various\n(non-commercial use only)', 
+                'livecell BV2 + SkBr3\n(non-commercial use only)', 'livecell SHSY5Y\n(non-commercial use only)']
         for j in range(9):
-            self.StyleButtons.append(guiparts.ModelButton(self, net_text[j], net_text[j]))
+            self.StyleButtons.append(guiparts.ModelButton(self, self.net_text[j+5], self.net_text[j+5]))
             self.GBg.addWidget(self.StyleButtons[-1], 1,j,1,1)
             self.StyleButtons[-1].setFixedWidth(22)
             self.StyleButtons[-1].setToolTip(nett[j])
 
+        self.StyleToModel = QPushButton(' compute style and run suggested model')
+        self.StyleToModel.setStyleSheet(self.styleInactive)
+        self.StyleToModel.clicked.connect(self.suggest_model)
+        self.StyleToModel.setToolTip(' uses general cp2 model to compute style and runs suggested model based on style')
+        self.StyleToModel.setFont(self.smallfont)
+        self.GBg.addWidget(self.StyleToModel, 2,0,1,10)
+
         self.l0.addWidget(self.GB, b, 0, 2, 9)
 
         b+=2
@@ -545,7 +563,7 @@ class MainW(QMainWindow):
         
         self.CBg.addWidget(self.ModelChoose, 0,0,1,7)
 
-        # recompute segmentation
+        # compute segmentation w/ custom model
         self.ModelButton = QPushButton(u'run model')
         self.ModelButton.clicked.connect(self.compute_model)
         self.CBg.addWidget(self.ModelButton, 0,7,2,2)
@@ -557,7 +575,13 @@ class MainW(QMainWindow):
         b+=1
         self.progress = QProgressBar(self)
         self.progress.setStyleSheet('color: gray;')
-        self.l0.addWidget(self.progress, b,0,1,9)
+        self.l0.addWidget(self.progress, b,0,1,5)
+
+        self.roi_count = QLabel('0 ROIs')
+        self.roi_count.setStyleSheet('color: white;')
+        self.roi_count.setFont(self.boldfont)
+        self.roi_count.setAlignment(QtCore.Qt.AlignRight)
+        self.l0.addWidget(self.roi_count, b,5,1,3)
 
         b+=1
         line = QHLine()
@@ -653,6 +677,16 @@ class MainW(QMainWindow):
         self.zpos.returnPressed.connect(self.update_ztext)
         self.zpos.setFixedWidth(60)
         self.l0.addWidget(self.zpos, b, 6,1,3)
+        
+        # scale toggle
+        self.scale_on = True
+        self.ScaleOn = QCheckBox('scale disk on')
+        self.ScaleOn.setFont(self.medfont)
+        self.ScaleOn.setStyleSheet('color: rgb(150,50,150);')
+        self.ScaleOn.setChecked(True)
+        self.ScaleOn.setToolTip('see current diameter as red disk at bottom')
+        self.ScaleOn.toggled.connect(self.toggle_scale)
+        self.l0.addWidget(self.ScaleOn, b,0,1,4)
 
         # add scrollbar underneath
         self.scroll = QScrollBar(QtCore.Qt.Horizontal)
@@ -674,10 +708,12 @@ class MainW(QMainWindow):
                     if self.NZ>1:
                         if event.key() == QtCore.Qt.Key_Left:
                             self.currentZ = max(0,self.currentZ-1)
-                            self.zpos.setText(str(self.currentZ))
+                            self.scroll.setValue(self.currentZ)
+                            updated = True
                         elif event.key() == QtCore.Qt.Key_Right:
                             self.currentZ = min(self.NZ-1, self.currentZ+1)
-                            self.zpos.setText(str(self.currentZ))
+                            self.scroll.setValue(self.currentZ)
+                            updated = True
                 else:
                     if event.key() == QtCore.Qt.Key_X:
                         self.MCheckBox.toggle()
@@ -894,6 +930,7 @@ class MainW(QMainWindow):
             self.currentZ = min(self.NZ, max(0, int(self.scroll.value())))
             self.zpos.setText(str(self.currentZ))
             self.update_plot()
+            self.draw_layer()
             self.update_layer()
             
             
@@ -905,6 +942,7 @@ class MainW(QMainWindow):
             border=[100, 100, 100],
             invertY=True
         )
+        self.p0.setCursor(QtCore.Qt.CrossCursor)
         self.brush_size=3
         self.win.addItem(self.p0, 0, 0, rowspan=1, colspan=1)
         self.p0.setMenuEnabled(False)
@@ -1037,7 +1075,6 @@ class MainW(QMainWindow):
         self.flows = [[],[],[],[],[[]]]
         self.stack = np.zeros((1,self.Ly,self.Lx,3))
         # masks matrix
-        self.layers = 0*np.ones((1,self.Ly,self.Lx,4), np.uint8)
         self.layerz = 0*np.ones((self.Ly,self.Lx,4), np.uint8)
         # image matrix with a scale disk
         self.radii = 0*np.ones((self.Ly,self.Lx,4), np.uint8)
@@ -1066,8 +1103,6 @@ class MainW(QMainWindow):
     def clear_all(self):
         self.prev_selected = 0
         self.selected = 0
-        #self.layers_undo, self.cellpix_undo, self.outpix_undo = [],[],[]
-        self.layers = 0*np.ones((self.NZ,self.Ly,self.Lx,4), np.uint8)
         self.layerz = 0*np.ones((self.Ly,self.Lx,4), np.uint8)
         self.cellpix = np.zeros((self.NZ,self.Ly,self.Lx), np.uint32)
         self.outpix = np.zeros((self.NZ,self.Ly,self.Lx), np.uint32)
@@ -1082,8 +1117,6 @@ class MainW(QMainWindow):
         if self.selected > 0:
             z = self.currentZ
             self.layerz[self.cellpix[z]==idx] = np.array([255,255,255,self.opacity])
-            #if self.outlinesOn:
-            #    self.layers[self.outpix==idx] = np.array(self.outcolor)
             self.update_layer()
 
     def unselect_cell(self):
@@ -1191,13 +1224,13 @@ class MainW(QMainWindow):
             self.redo.setEnabled(False)
 
 
-    def remove_stroke(self, delete_points=True):
+    def remove_stroke(self, delete_points=True, stroke_ind=-1):
         #self.current_stroke = get_unique_points(self.current_stroke)
-        stroke = np.array(self.strokes[-1])
-        inZ = stroke[0,0]==self.currentZ
+        stroke = np.array(self.strokes[stroke_ind])
         cZ = self.currentZ
+        inZ = stroke[0,0]==cZ
         if inZ:
-            outpix = self.outpix[self.currentZ, stroke[:,1],stroke[:,2]]>0
+            outpix = self.outpix[cZ, stroke[:,1],stroke[:,2]]>0
             self.layerz[stroke[~outpix,1],stroke[~outpix,2]] = np.array([0,0,0,0])
             cellpix = self.cellpix[cZ, stroke[:,1], stroke[:,2]]
             ccol = self.cellcolors.copy()
@@ -1213,8 +1246,9 @@ class MainW(QMainWindow):
                 self.layerz[stroke[outpix,1],stroke[outpix,2]] = np.array(self.outcolor)
             if delete_points:
                 self.current_point_set = self.current_point_set[:-1*(stroke[:,-1]==1).sum()]
-            del self.strokes[-1]
             self.update_layer()
+            
+        del self.strokes[stroke_ind]
 
     def plot_clicked(self, event):
         if event.button()==QtCore.Qt.LeftButton and (event.modifiers() != QtCore.Qt.ShiftModifier and
@@ -1242,14 +1276,9 @@ class MainW(QMainWindow):
     def mouse_moved(self, pos):
         items = self.win.scene().items(pos)
         #for x in items:
-        #    if x==self.p0:
-        #        mousePoint = self.p0.mapSceneToView(pos)
-        #        if self.orthobtn.isChecked():
-        #            self.vLine.setPos(mousePoint.x())
-        #            self.hLine.setPos(mousePoint.y())
-            #else:
-            #    QtWidgets.QApplication.restoreOverrideCursor()
-                #QtWidgets.QApplication.setOverrideCursor(QtCore.Qt.DefaultCursor)
+        #    if not x==self.p0:
+        #        QtWidgets.QApplication.restoreOverrideCursor()
+        #        QtWidgets.QApplication.setOverrideCursor(QtCore.Qt.DefaultCursor)
 
 
     def color_choose(self):
@@ -1312,11 +1341,15 @@ class MainW(QMainWindow):
 
     def update_layer(self):
         if self.masksOn or self.outlinesOn:
-            self.draw_layer()
+            #self.draw_layer()
             self.layer.setImage(self.layerz, autoLevels=False)
+        self.update_roi_count()
         self.win.show()
         self.show()
 
+    def update_roi_count(self):
+        self.roi_count.setText(f'{self.ncells} ROIs')
+
     def update_ortho(self):
         if self.NZ>1 and self.orthobtn.isChecked():
             dzcurrent = self.dz
@@ -1486,14 +1519,17 @@ class MainW(QMainWindow):
     def compute_scale(self):
         self.diameter = float(self.Diameter.text())
         self.pr = int(float(self.Diameter.text()))
-        radii = np.zeros((self.Ly+self.pr,self.Lx), np.uint8)
-        self.radii = np.zeros((self.Ly+self.pr,self.Lx,4), np.uint8)
-        yy,xx = disk([self.Ly+self.pr/2-1, self.pr/2+1],
-                            self.pr/2, self.Ly+self.pr, self.Lx)
-        self.radii[yy,xx,0] = 255
-        self.radii[yy,xx,-1] = 255#self.opacity * (radii>0)
+        self.radii_padding = int(self.pr*1.25)
+        self.radii = np.zeros((self.Ly+self.radii_padding,self.Lx,4), np.uint8)
+        yy,xx = disk([self.Ly+self.radii_padding/2-1, self.pr/2+1],
+                            self.pr/2, self.Ly+self.radii_padding, self.Lx)
+        # rgb(150,50,150)
+        self.radii[yy,xx,0] = 150
+        self.radii[yy,xx,1] = 50
+        self.radii[yy,xx,2] = 150
+        self.radii[yy,xx,3] = 255
         self.update_plot()
-        self.p0.setYRange(0,self.Ly+self.pr)
+        self.p0.setYRange(0,self.Ly+self.radii_padding)
         self.p0.setXRange(0,self.Lx)
         self.win.show()
         self.show()
@@ -1506,10 +1542,18 @@ class MainW(QMainWindow):
 
     def draw_layer(self):
         if self.masksOn:
+            self.layerz = np.zeros((self.Ly,self.Lx,4), np.uint8)
             self.layerz[...,:3] = self.cellcolors[self.cellpix[self.currentZ],:]
             self.layerz[...,3] = self.opacity * (self.cellpix[self.currentZ]>0).astype(np.uint8)
             if self.selected>0:
                 self.layerz[self.cellpix[self.currentZ]==self.selected] = np.array([255,255,255,self.opacity])
+            cZ = self.currentZ
+            stroke_z = np.array([s[0][0] for s in self.strokes])
+            inZ = np.nonzero(stroke_z == cZ)[0]
+            if len(inZ) > 0:
+                for i in inZ:
+                    stroke = np.array(self.strokes[i])
+                    self.layerz[stroke[:,1], stroke[:,2]] = np.array([255,0,255,100])
         else:
             self.layerz[...,3] = 0
 
@@ -1563,11 +1607,6 @@ class MainW(QMainWindow):
             
     def add_model(self):
         io._add_model(self)
-        #a_list = ["abc", "def", "ghi"]
-        #textfile = open("a_file.txt", "w")
-        #for element in a_list:
-        #    textfile.write(element + "\n")
-        #textfile.close()
         return
 
     def remove_model(self):
@@ -1676,6 +1715,33 @@ class MainW(QMainWindow):
             io._masks_to_gui(self, maski, outlines=None)
             self.show()
 
+    def suggest_model(self, model_name=None):
+        logger.info('computing styles with 2D image...')
+        data = self.stack[self.NZ//2].copy()
+        styles_gt = np.load(os.fspath(pathlib.Path.home().joinpath('.cellpose', 'style_choice.npy')), 
+                            allow_pickle=True).item()
+        train_styles, train_labels, label_models = styles_gt['train_styles'], styles_gt['leiden_labels'], styles_gt['label_models']
+        self.diameter = float(self.Diameter.text())
+        self.current_model = 'general'
+        channels = self.get_channels()
+        model = models.CellposeModel(model_type='general', gpu=self.useGPU.isChecked())
+        styles = model.eval(data, 
+                            channels=channels, 
+                            diameter=self.diameter, 
+                            compute_masks=False)[-1]
+
+        n_neighbors = 5
+        dists = ((train_styles - styles)**2).sum(axis=1)**0.5
+        neighbor_labels = train_labels[dists.argsort()[:n_neighbors]]
+        label = mode(neighbor_labels)[0][0]
+        model_type = label_models[label]
+        logger.info(f'style suggests model {model_type}')
+        ind = self.net_text.index(model_type)
+        for i in range(len(self.net_text)):
+            self.StyleButtons[i].setStyleSheet(self.styleUnpressed)
+        self.StyleButtons[ind].setStyleSheet(self.stylePressed)
+        self.compute_model(model_name=model_type)
+            
     def compute_model(self, model_name=None):
         self.progress.setValue(0)
         try:
@@ -1685,8 +1751,11 @@ class MainW(QMainWindow):
             self.initialize_model(model_name)
             self.progress.setValue(10)
             do_3D = False
+            stitch_threshold = False
             if self.NZ > 1:
-                do_3D = True
+                stitch_threshold = float(self.stitch_threshold.text())
+                stitch_threshold = 0 if stitch_threshold <= 0 or stitch_threshold > 1 else stitch_threshold
+                do_3D = True if stitch_threshold==0 else False
                 data = self.stack.copy()
             else:
                 data = self.stack[0].copy()
@@ -1699,7 +1768,8 @@ class MainW(QMainWindow):
                                                 diameter=self.diameter,
                                                 cellprob_threshold=cellprob_threshold,
                                                 flow_threshold=flow_threshold,
-                                                do_3D=do_3D, 
+                                                do_3D=do_3D,
+                                                stitch_threshold=stitch_threshold, 
                                                 progress=self.progress)[:2]
             except Exception as e:
                 print('NET ERROR: %s'%e)
@@ -1712,12 +1782,12 @@ class MainW(QMainWindow):
             #    flows = flows[0]
             self.flows[0] = flows[0].copy() #RGB flow
             self.flows[1] = (np.clip(normalize99(flows[2].copy()), 0, 1) * 255).astype(np.uint8) #dist/prob
-            if not do_3D:
+            if not do_3D and not stitch_threshold > 0:
                 masks = masks[np.newaxis,...]
                 self.flows[0] = resize_image(self.flows[0], masks.shape[-2], masks.shape[-1],
                                                         interpolation=cv2.INTER_NEAREST)
                 self.flows[1] = resize_image(self.flows[1], masks.shape[-2], masks.shape[-1])
-            if not do_3D:
+            if not do_3D and not stitch_threshold > 0:
                 self.flows[2] = np.zeros(masks.shape[1:], dtype=np.uint8)
                 self.flows = [self.flows[n][np.newaxis,...] for n in range(len(self.flows))]
             else:
@@ -1737,8 +1807,10 @@ class MainW(QMainWindow):
             io._masks_to_gui(self, masks, outlines=None)
             self.progress.setValue(100)
 
-            if not do_3D:
+            if not do_3D and not stitch_threshold > 0:
                 self.recompute_masks = True
+            else:
+                self.recompute_masks = False
         except Exception as e:
             print('ERROR: %s'%e)
 
@@ -1746,10 +1818,13 @@ class MainW(QMainWindow):
         if len(self.model_strings) > 0:
             self.ModelButton.setStyleSheet(self.styleUnpressed)
             self.ModelButton.setEnabled(True)
+        self.StyleToModel.setStyleSheet(self.styleUnpressed)
+        self.StyleToModel.setEnabled(True)
         for i in range(len(self.StyleButtons)):
             self.StyleButtons[i].setEnabled(True)
             self.StyleButtons[i].setStyleSheet(self.styleUnpressed)
         self.SizeButton.setEnabled(True)
+        self.SCheckBox.setEnabled(True)
         self.SizeButton.setStyleSheet(self.styleUnpressed)
         self.newmodel.setEnabled(True)
         self.loadMasks.setEnabled(True)
