@@ -1,3 +1,4 @@
+import PyQt5
 from PyQt5 import QtGui, QtCore, QtWidgets
 from PyQt5.QtGui import QPainter, QPixmap
 from PyQt5.QtWidgets import QApplication, QRadioButton, QWidget, QDialog, QButtonGroup, QSlider, QStyle, QStyleOptionSlider, QGridLayout, QPushButton, QLabel, QLineEdit, QDialogButtonBox, QComboBox, QCheckBox
@@ -36,12 +37,15 @@ class ModelButton(QPushButton):
         self.model_name = model_name
         
     def press(self, parent):
+        for i in range(len(parent.StyleButtons)):
+            parent.StyleButtons[i].setStyleSheet(parent.styleUnpressed)
+        self.setStyleSheet(parent.stylePressed)
         parent.compute_model(self.model_name)
 
 class TrainWindow(QDialog):
     def __init__(self, parent, model_strings):
         super().__init__(parent)
-        self.setGeometry(100,100,600,300)
+        self.setGeometry(100,100,900,350)
         self.setWindowTitle('train settings')
         self.win = QWidget(self)
         self.l0 = QGridLayout()
@@ -85,16 +89,17 @@ class TrainWindow(QDialog):
             self.l0.addWidget(qlabel, i+yoff,0,1,1)
             self.edits.append(QLineEdit())
             self.edits[-1].setText(str(parent.training_params[label]))
+            self.edits[-1].setFixedWidth(200)
             self.l0.addWidget(self.edits[-1], i+yoff, 1,1,1)
 
         yoff+=len(labels)
 
         yoff+=1
-        qlabel = QLabel('(to remove files, click cancel then remove from folder and reopen train window)')
-        self.l0.addWidget(qlabel, yoff,0,1,4)
+        qlabel = QLabel('(to remove files, click cancel then remove \nfrom folder and reopen train window)')
+        self.l0.addWidget(qlabel, yoff,0,2,4)
 
         # click button
-        yoff+=1
+        yoff+=2
         QBtn = QDialogButtonBox.Ok | QDialogButtonBox.Cancel
         self.buttonBox = QDialogButtonBox(QBtn)
         self.buttonBox.accepted.connect(lambda: self.accept(parent))
@@ -433,7 +438,7 @@ class RGBRadioButtons(QButtonGroup):
                 button.setChecked(True)
             self.addButton(button, b)
             button.toggled.connect(lambda: self.btnpress(parent))
-            self.parent.l0.addWidget(button, row+b,col,1,3)
+            self.parent.l0.addWidget(button, row,col+2*b,1,2)
         self.setExclusive(True)
         #self.buttons.
 
@@ -577,7 +582,7 @@ class ImageDraw(pg.ImageItem):
         return
 
     def hoverEvent(self, ev):
-        QtWidgets.QApplication.setOverrideCursor(QtCore.Qt.CrossCursor)
+        #QtWidgets.QApplication.setOverrideCursor(QtCore.Qt.CrossCursor)
         if self.parent.in_stroke:
             if self.parent.in_stroke:
                 # continue stroke if not at start
@@ -636,7 +641,7 @@ class ImageDraw(pg.ImageItem):
         #print(ev.pressure())
 
     def drawAt(self, pos, ev=None):
-        mask = self.greenmask
+        mask = self.strokemask
         set = self.parent.current_point_set
         stroke = self.parent.current_stroke
         pos = [int(pos.y()), int(pos.x())]
@@ -691,7 +696,7 @@ class ImageDraw(pg.ImageItem):
         offmask = np.zeros((bs,bs,1))
         opamask = 100 * kernel[:,:,np.newaxis]
         self.redmask = np.concatenate((onmask,offmask,offmask,onmask), axis=-1)
-        self.greenmask = np.concatenate((onmask,offmask,onmask,opamask), axis=-1)
+        self.strokemask = np.concatenate((onmask,offmask,onmask,opamask), axis=-1)
 
 
 class RangeSlider(QSlider):
@@ -722,12 +727,12 @@ class RangeSlider(QSlider):
         self.setStyleSheet(\
                 "QSlider::handle:horizontal {\
                 background-color: white;\
-                border: 1px solid #5c5c5c;\
-                border-radius: 0px;\
-                border-color: black;\
+                border: 1px solid white;\
+                border-radius: 2px;\
+                border-color: white;\
                 height: 8px;\
                 width: 6px;\
-                margin: -8px 2; \
+                margin: 0px 2; \
                 }")
 
 
@@ -784,8 +789,8 @@ class RangeSlider(QSlider):
             else:
                 opt.activeSubControls = self.hover_control
 
-            opt.sliderPosition = value
-            opt.sliderValue = value
+            opt.sliderPosition = int(value)
+            opt.sliderValue = int(value)
             style.drawComplexControl(QStyle.CC_Slider, opt, painter, self)
 
 
