@@ -1,4 +1,4 @@
-import os, datetime, gc, warnings, glob
+import os, datetime, gc, warnings, glob, shutil
 from natsort import natsorted
 import numpy as np
 import cv2
@@ -7,8 +7,10 @@ import logging, pathlib, sys
 from tqdm import tqdm
 from pathlib import Path
 
+
 try:
     from PyQt5 import QtGui, QtCore, Qt, QtWidgets
+    from PyQt5.QtWidgets import QMessageBox
     GUI = True
 except:
     GUI = False
@@ -65,7 +67,9 @@ def outlines_to_text(base, outlines):
             f.write('\n')
 
 def imread(filename):
-    ext = os.path.splitext(filename)[-1]
+    """ read in image with tif or image file type supported by cv2 """
+    # ensure that extension check is not case sensitive
+    ext = os.path.splitext(filename)[-1].lower()
     if ext== '.tif' or ext=='.tiff':
         with tifffile.TiffFile(filename) as tif:
             ltif = len(tif.pages)
@@ -107,11 +111,40 @@ def imread(filename):
             io_logger.critical('ERROR: could not read masks from file, %s'%e)
             return None
 
+def remove_model(filename, delete=False):
+    """ remove model from .cellpose custom model list """
+    filename = os.path.split(filename)[-1]
+    from . import models
+    model_strings = models.get_user_models()
+    if len(model_strings) > 0:
+        with open(models.MODEL_LIST_PATH, 'w') as textfile:
+            for fname in model_strings:
+                textfile.write(fname + '\n')
+    else:
+        # write empty file
+        textfile = open(models.MODEL_LIST_PATH, 'w')
+        textfile.close()
+    print(f'{filename} removed from custom model list')
+    if delete:
+        os.remove(os.fspath(models.MODEL_DIR.joinpath(fname)))
+        print('model deleted')
+
+def add_model(filename):
+    """ add model to .cellpose models folder to use with GUI or CLI """
+    from . import models
+    fname = os.path.split(filename)[-1]
+    try:
+        shutil.copyfile(filename, os.fspath(models.MODEL_DIR.joinpath(fname)))
+    except shutil.SameFileError:
+        pass
+    print(f'{filename} copied to models folder {os.fspath(models.MODEL_DIR)}')
+    with open(models.MODEL_LIST_PATH, 'a') as textfile:
+        textfile.write(fname + '\n')
 
 def imsave(filename, arr):
-    ext = os.path.splitext(filename)[-1]
+    ext = os.path.splitext(filename)[-1].lower()
     if ext== '.tif' or ext=='.tiff':
-        tifffile.imsave(filename, arr)
+        tifffile.imwrite(filename, arr)
     else:
         if len(arr.shape)>2:
             arr = cv2.cvtColor(arr, cv2.COLOR_BGR2RGB)
@@ -129,13 +162,23 @@ def get_image_files(folder, mask_filter, imf=None, look_one_level_down=False):
     if look_one_level_down:
         folders = natsorted(glob.glob(os.path.join(folder, "*/")))
     folders.append(folder)
-
+    exts = ['.png', '.jpg', '.jpeg', '.tif', '.tiff']
+    l0 = 0
+    al = 0
     for folder in folders:
-        image_names.extend(glob.glob(folder + '/*%s.png'%imf))
-        image_names.extend(glob.glob(folder + '/*%s.jpg'%imf))
-        image_names.extend(glob.glob(folder + '/*%s.jpeg'%imf))
-        image_names.extend(glob.glob(folder + '/*%s.tif'%imf))
-        image_names.extend(glob.glob(folder + '/*%s.tiff'%imf))
+        all_files = glob.glob(folder + '/*')
+        al += len(all_files)
+        for ext in exts:
+            image_names.extend(glob.glob(folder + f'/*{imf}{ext}'))
+            image_names.extend(glob.glob(folder + f'/*{imf}{ext.upper()}'))
+        l0 += len(image_names)
+    
+    # return error if no files found
+    if al==0:
+        raise ValueError('ERROR: no files in --dir folder ')
+    elif l0==0:
+        raise ValueError("ERROR: no images in --dir folder with extensions '.png', '.jpg', '.jpeg', '.tif', '.tiff'")
+
     image_names = natsorted(image_names)
     imn = []
     for im in image_names:
@@ -147,10 +190,10 @@ def get_image_files(folder, mask_filter, imf=None, look_one_level_down=False):
         if igood:
             imn.append(im)
     image_names = imn
-
-    if len(image_names)==0:
-        raise ValueError('ERROR: no images in --dir folder')
     
+    if len(image_names)==0:
+        raise ValueError('ERROR: no images in --dir folder without _masks or _flows ending')
+        
     return image_names
         
 def get_label_files(image_names, mask_filter, imf=None):
@@ -342,7 +385,7 @@ def save_masks(images, masks, flows, file_names, png=True, tif=False, channels=[
 
     if png and matplotlib installed, full segmentation figure is saved to file_names[k]+'_cp.png'
 
-    only tif option works for 3D data
+    only tif option works for 3D data, and only tif option works for empty masks
     
     Parameters
     -------------
@@ -379,7 +422,16 @@ def save_masks(images, masks, flows, file_names, png=True, tif=False, channels=[
     
     if masks.ndim > 2 and not tif:
         raise ValueError('cannot save 3D outputs as PNG, use tif option instead')
-#     base = os.path.splitext(file_names)[0]
+    
+    if masks.max() == 0:
+        io_logger.warning('no masks found, will not save PNG or outlines')
+        if not tif:
+            return
+        else:
+            png = False 
+            save_outlines=False 
+            save_flows=False
+            save_txt=False
     
     if savedir is None: 
         if dir_above:
@@ -480,13 +532,13 @@ def save_server(parent=None, filename=None):
         if no GUI, send this file to server
     """
     if parent is not None:
-        q = QtGui.QMessageBox.question(
+        q = QMessageBox.question(
                                     parent,
                                     "Send to server",
                                     "Are you sure? Only send complete and fully manually segmented data.\n (do not send partially automated segmentations)",
-                                    QtGui.QMessageBox.Yes | QtGui.QMessageBox.No
+                                    QMessageBox.Yes | QMessageBox.No
                                   )
-        if q != QtGui.QMessageBox.Yes:
+        if q != QMessageBox.Yes:
             return
         else:
             filename = parent.filename
