@@ -16,9 +16,11 @@ _MODEL_DIR_ENV = os.environ.get("CELLPOSE_LOCAL_MODELS_PATH")
 _MODEL_DIR_DEFAULT = pathlib.Path.home().joinpath('.cellpose', 'models')
 MODEL_DIR = pathlib.Path(_MODEL_DIR_ENV) if _MODEL_DIR_ENV else _MODEL_DIR_DEFAULT
 
-MODEL_NAMES = ['cyto','nuclei','tissuenet','livecell', 'cyto2',
+MODEL_NAMES = ['cyto','nuclei','tissuenet','livecell', 'cyto2', 'general',
                 'CP', 'CPx', 'TN1', 'TN2', 'TN3', 'LC1', 'LC2', 'LC3', 'LC4']
 
+MODEL_LIST_PATH = os.fspath(MODEL_DIR.joinpath('gui_models.txt'))
+
 def model_path(model_type, model_index, use_torch=True):
     torch_str = 'torch'
     if model_type=='cyto' or model_type=='cyto2' or model_type=='nuclei':
@@ -42,10 +44,9 @@ def cache_model_path(basename):
     return cached_file
 
 def get_user_models():
-    model_list_path = os.fspath(MODEL_DIR.joinpath('gui_models.txt'))
     model_strings = []
-    if os.path.exists(model_list_path):
-        with open(model_list_path, 'r') as textfile:
+    if os.path.exists(MODEL_LIST_PATH):
+        with open(MODEL_LIST_PATH, 'r') as textfile:
             lines = [line.rstrip() for line in textfile]
             if len(lines) > 0:
                 model_strings.extend(lines)
@@ -135,7 +136,7 @@ class Cellpose():
             invert image pixel intensity before running network (if True, image is also normalized)
 
         normalize: bool (optional, default True)
-                normalize data so 0.0=1st percentile and 1.0=99th percentile of image intensities in each channel
+            normalize data so 0.0=1st percentile and 1.0=99th percentile of image intensities in each channel
 
         diameter: float (optional, default 30.)
             if set to None, then diameter is automatically estimated if size model is loaded
